c$Id:$
      subroutine usolve(flags,b)

c      * * F E A P * * A Finite Element Analysis Program

c....  Copyright (c) 1984-2001: Regents of the University of California
c                               All rights reserved

c-----[--.----+----.----+----.-----------------------------------------]
c     Purpose:  Solver interface for SuperLU

c     Inputs:
c        flags(1) - Allocation and/or initialization phase
c        flags(2) - Perform factorization for direct solutions
c        flags(3) - Coefficient array unsymmetric
c        flags(4) - Solve equations
c        flags(5) - Purge storage of pointers 
c        b(*)     - RHS vector

c     Outputs:

c        flags(5) - True if error occurs (for factor/solve only)
c-----[--.----+----.----+----.-----------------------------------------]

      implicit  none

      include  'cdata.h'
      include  'endata.h'
      include  'part0.h'
      include  'setups.h'
      include  'pointer.h'
      include  'comblk.h'

      character tname*5
      logical   flags(*), setvar,palloc, uflag
      integer   i,nnu,nrhs,info, ibsv, factor(8)
      real*8    b(*), dot

      save

      data      uflag / .false. /

c     Presolve setups

      if(flags(1)) then

c       Establish current matrix indices

        call iters(nnu,-1)

c       Allocate matrix storage

        write(tname,'(4hTANG,i1)') npart
        setvar = palloc(npart,tname,nnu,2)
        call pzero(hr(np(npart)),nnu)

c     Solution steps for assembled equations

      else

        nrhs = 1

c       Factor equations

        if(flags(2)) then

c         Purge storage from solver 

          if(uflag) then
            call c_fortran_dgssv(3, neq, nnu, nrhs, hr(np(npart)),
     &                           mr(np(226)), mr(np(227)), hr(np(26)),
     &                           neq, factor, info, processor)
          else
            uflag = .true.
          endif

c         Create column pointer array in SuperLU format

          setvar = palloc(227,'USOL3',neq+1,1)
          mr(np(227)) = 1
          do i = 1,neq
            mr(np(227)+i) = mr(np(225)+i-1) + 1
          end do ! i

c         Perform factor

          call c_fortran_dgssv(1, neq, nnu, nrhs, hr(np(npart)),
     &                         mr(np(226)), mr(np(227)), hr(np(26)),
     &                         neq, factor, info, processor)
        endif

c       Perform solve

        if(flags(4)) then

          setvar = palloc(228,'USOL4',neq  ,2)
          ibsv        = np(228) - 1
          do i = 1,neq
            hr(ibsv   +i) = b(i)
          end do ! i

          call c_fortran_dgssv(2, neq, nnu, nrhs, hr(np(npart)),
     &                         mr(np(226)), mr(np(227)), b,
     &                         neq, factor, info, processor)

c         Compute 'energy' for convergence test

          aengy  = dot(b,hr(np(228)),neq)
          setvar = palloc(228,'USOL4',    0,2)

        endif

c       Purge storage in 'factor'

        if(flags(5)) then

          call c_fortran_dgssv(3, neq, nnu, nrhs, hr(np(npart)),
     &                         mr(np(226)), mr(np(227)), hr(np(26)),
     &                         neq, factor, info, processor)

c         Delete temporary arrays

          setvar = palloc(227,'USOL3',    0,1)
          setvar = palloc(226,'USOL2',    0,1)  ! allocated in uiters
          setvar = palloc(225,'USOL1',    0,1)  ! allocated in uiters
        endif

c       write(*,*) 'INFO:',info

      endif

      end
